@@ -277,18 +277,20 @@ async def load_interfaces(hub):
     interface: str
     device: Dict[str, Any]
     for interface, device in interfaces.items():
+        if not interface:
+            continue
         hw_addr = device.get("hwaddr")
         if hw_addr:
             hub.corn.CORN.hwaddr_interfaces[interface] = hw_addr
         inet4: List[str] = [ip.get("address") for ip in device.get("inet", [])]
         ipv4.extend(inet4)
         if inet4:
-            hub.corn.CORN.ip4_interfaces[interface] = inet4
+            hub.corn.CORN.ip4_interfaces[interface] = sorted(inet4)
         inet6: List[str] = [ip.get("address") for ip in device.get("inet6", [])]
         ipv6.extend(inet6)
         if inet6:
-            hub.corn.CORN.ip6_interfaces[interface] = inet6
-        hub.corn.CORN.ip_interfaces[interface] = inet4 + inet6
+            hub.corn.CORN.ip6_interfaces[interface] = sorted(inet6)
+        hub.corn.CORN.ip_interfaces[interface] = sorted(inet4) + sorted(inet6)
 
-    hub.corn.CORN.ipv4 = ipv4
-    hub.corn.CORN.ipv6 = ipv6
+    hub.corn.CORN.ipv4 = sorted(ipv4)
+    hub.corn.CORN.ipv6 = sorted(ipv6)
